LRUCache (py4j-java 0.10.9.7 API)

Package py4j.reflection

## Class LRUCache<K,​V>

- java.lang.Object
- - java.util.AbstractMap<K,​V>
  - - java.util.HashMap<K,​V>
    - - java.util.LinkedHashMap<K,​V>
      - - py4j.reflection.LRUCache<K,​V>

- Type Parameters:
    `K` -
    `V` -
  All Implemented Interfaces:
    `java.io.Serializable`, `java.lang.Cloneable`, `java.util.Map<K,​V>`

      public class LRUCache<K,​V>
      extends java.util.LinkedHashMap<K,​V>

  Implementation of a Least Recently Used cache. Currently used by the ReflectionEngine to cache resolution of Java members.

  See Also:
    Serialized Form

- - ### Nested Class Summary

    - ### Nested classes/interfaces inherited from class java.util.AbstractMap

      `java.util.AbstractMap.SimpleEntry<K extends java.lang.Object,​V extends java.lang.Object>, java.util.AbstractMap.SimpleImmutableEntry<K extends java.lang.Object,​V extends java.lang.Object>`

  - ### Field Summary

    Fields
    Modifier and Type | Field | Description
    --- | --- | ---
    `static int` | `DEFAULT_CACHE_SIZE` |

  - ### Constructor Summary

    Constructors
    Constructor | Description
    --- | ---
    `LRUCache()` |
    `LRUCache​(int cacheSize)` |

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `protected boolean` | `removeEldestEntry​(java.util.Map.Entry<K,​V> eldest)` |

    - ### Methods inherited from class java.util.LinkedHashMap

      `clear, containsValue, entrySet, forEach, get, getOrDefault, keySet, replaceAll, values`

    - ### Methods inherited from class java.util.HashMap

      `clone, compute, computeIfAbsent, computeIfPresent, containsKey, isEmpty, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, size`

    - ### Methods inherited from class java.util.AbstractMap

      `equals, hashCode, toString`

    - ### Methods inherited from class java.lang.Object

      `finalize, getClass, notify, notifyAll, wait, wait, wait`

    - ### Methods inherited from interface java.util.Map

      `compute, computeIfAbsent, computeIfPresent, containsKey, equals, hashCode, isEmpty, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, size`

- - ### Field Detail

    - #### DEFAULT_CACHE_SIZE

          public static final int DEFAULT_CACHE_SIZE

      See Also:
        Constant Field Values

  - ### Constructor Detail

    - #### LRUCache

          public LRUCache()

    - #### LRUCache

          public LRUCache​(int cacheSize)

  - ### Method Detail

    - #### removeEldestEntry

          protected boolean removeEldestEntry​(java.util.Map.Entry<K,​V> eldest)

      Overrides:
        `removeEldestEntry` in class `java.util.LinkedHashMap<K,​V>`